@@ -13,26 +13,26 @@ QwtPainterClass
    :members:
 """
 
-from .color_map import QwtColorMap
-from .scale_map import QwtScaleMap
-
-from .qt.QtGui import (
-    QPaintEngine,
-    QFrame,
-    QPixmap,
-    QPainter,
-    QPalette,
-    QStyle,
-    QPen,
-    QStyleOptionFocusRect,
+from qtpy import QtCore as QC
+from qtpy.QtCore import QLineF, QPoint, QRect, QRectF, Qt
+from qtpy.QtGui import (
     QBrush,
-    QRegion,
-    QLinearGradient,
-    QPainterPath,
     QColor,
-    QStyleOption,
+    QLinearGradient,
+    QPaintEngine,
+    QPainter,
+    QPainterPath,
+    QPalette,
+    QPen,
+    QPixmap,
+    QRegion,
 )
-from .qt.QtCore import Qt, QRect, QPoint, QT_VERSION, QRectF
+from qtpy.QtWidgets import QFrame, QStyle, QStyleOption, QStyleOptionFocusRect
+
+from qwt.color_map import QwtColorMap
+from qwt.scale_map import QwtScaleMap
+
+QT_MAJOR_VERSION = int(QC.__version__.split(".")[0])
 
 QWIDGETSIZE_MAX = (1 << 24) - 1
 
@@ -64,26 +64,10 @@ class QwtPainterClass(object):
     """A collection of `QPainter` workarounds"""
 
     def drawImage(self, painter, rect, image):
-        alignedRect = rect.toAlignedRect()
-        if alignedRect != rect:
-            clipRect = rect.adjusted(0.0, 0.0, -1.0, -1.0)
-            painter.save()
-            painter.setClipRect(clipRect, Qt.IntersectClip)
-            painter.drawImage(alignedRect, image)
-            painter.restore()
-        else:
-            painter.drawImage(alignedRect, image)
+        painter.drawImage(rect, image)
 
     def drawPixmap(self, painter, rect, pixmap):
-        alignedRect = rect.toAlignedRect()
-        if alignedRect != rect:
-            clipRect = rect.adjusted(0.0, 0.0, -1.0, -1.0)
-            painter.save()
-            painter.setClipRect(clipRect, Qt.IntersectClip)
-            painter.drawPixmap(alignedRect, pixmap)
-            painter.restore()
-        else:
-            painter.drawPixmap(alignedRect, pixmap)
+        painter.drawPixmap(rect, pixmap)
 
     def drawFocusRect(self, *args):
         if len(args) == 2:
@@ -107,7 +91,7 @@ class QwtPainterClass(object):
     def drawRoundFrame(self, painter, rect, palette, lineWidth, frameStyle):
         """
         Draw a round frame
-        
+
         :param QPainter painter: Painter
         :param QRectF rect: Target rectangle
         :param QPalette palette: `QPalette.WindowText` is used for plain borders, `QPalette.Dark` and `QPalette.Light` for raised or sunken borders
@@ -150,7 +134,7 @@ class QwtPainterClass(object):
     ):
         """
         Draw a rectangular frame
-        
+
         :param QPainter painter: Painter
         :param QRectF rect: Frame rectangle
         :param QPalette palette: Palette
@@ -269,7 +253,7 @@ class QwtPainterClass(object):
     ):
         """
         Draw a rectangular frame with rounded borders
-        
+
         :param QPainter painter: Painter
         :param QRectF rect: Frame rectangle
         :param float xRadius: x-radius of the ellipses defining the corners
@@ -357,7 +341,7 @@ class QwtPainterClass(object):
     def drawColorBar(self, painter, colorMap, interval, scaleMap, orientation, rect):
         """
         Draw a color bar into a rectangle
-        
+
         :param QPainter painter: Painter
         :param qwt.color_map.QwtColorMap colorMap: Color map
         :param qwt.interval.QwtInterval interval: Value range
@@ -384,7 +368,7 @@ class QwtPainterClass(object):
                 else:
                     c = colorTable[colorMap.colorIndex(interval, value)]
                 pmPainter.setPen(c)
-                pmPainter.drawLine(x, devRect.top(), x, devRect.bottom())
+                pmPainter.drawLine(QLineF(x, devRect.top(), x, devRect.bottom()))
         else:
             sMap = QwtScaleMap(scaleMap)
             sMap.setPaintInterval(rect.bottom(), rect.top())
@@ -395,24 +379,24 @@ class QwtPainterClass(object):
                 else:
                     c = colorTable[colorMap.colorIndex(interval, value)]
                 pmPainter.setPen(c)
-                pmPainter.drawLine(devRect.left(), y, devRect.right(), y)
+                pmPainter.drawLine(QLineF(devRect.left(), y, devRect.right(), y))
         pmPainter.end()
-        self.drawPixmap(painter, rect, pixmap)
+        self.drawPixmap(painter, devRect, pixmap)
 
     def fillPixmap(self, widget, pixmap, offset=None):
         """
         Fill a pixmap with the content of a widget
 
         In Qt >= 5.0 `QPixmap.fill()` is a nop, in Qt 4.x it is buggy
-        for backgrounds with gradients. Thus `fillPixmap()` offers 
+        for backgrounds with gradients. Thus `fillPixmap()` offers
         an alternative implementation.
-        
+
         :param QWidget widget: Widget
         :param QPixmap pixmap: Pixmap to be filled
         :param QPoint offset: Offset
-        
+
         .. seealso::
-        
+
             :py:meth:`QPixmap.fill()`
         """
         if offset is None:
@@ -435,19 +419,19 @@ class QwtPainterClass(object):
     def drawBackground(self, painter, rect, widget):
         """
         Fill rect with the background of a widget
-        
+
         :param QPainter painter: Painter
         :param QRectF rect: Rectangle to be filled
         :param QWidget widget: Widget
-        
+
         .. seealso::
-        
+
             :py:data:`QStyle.PE_Widget`, :py:meth:`QWidget.backgroundRole()`
         """
         if widget.testAttribute(Qt.WA_StyledBackground):
             opt = QStyleOption()
             opt.initFrom(widget)
-            opt.rect = QRectF(rect).toAlignedRect()
+            opt.rect = rect
             widget.style().drawPrimitive(QStyle.PE_Widget, opt, painter, widget)
         else:
             brush = widget.palette().brush(widget.backgroundRole())
@@ -459,12 +443,12 @@ class QwtPainterClass(object):
         :param QSize size: Size of the pixmap
         :return: A pixmap that can be used as backing store
         """
-        if QT_VERSION >= 0x050000:
+        if QT_MAJOR_VERSION >= 5:
             pixelRatio = 1.0
             if widget and widget.windowHandle():
                 pixelRatio = widget.windowHandle().devicePixelRatio()
             else:
-                from .qt.QtGui import qApp
+                from qtpy.QtGui import qApp
 
                 if qApp is not None:
                     try:
@@ -475,7 +459,7 @@ class QwtPainterClass(object):
             pm.setDevicePixelRatio(pixelRatio)
         else:
             pm = QPixmap(size)
-        if QT_VERSION < 0x050000 and widget and isX11GraphicsSystem():
+        if QT_MAJOR_VERSION < 5 and widget and isX11GraphicsSystem():
             if pm.x11Info().screen() != widget.x11Info().screen():
                 pm.x11SetScreen(widget.x11Info().screen())
         return pm
