@@ -13,28 +13,37 @@ QwtPlotCanvas
    :members:
 """
 
+import os
+
+from qtpy import QtCore as QC
+from qtpy.QtCore import QEvent, QPointF, QRect, QRectF, QSizeF, Qt
+from qtpy.QtGui import (
+    QBrush,
+    QGradient,
+    QImage,
+    QPaintEngine,
+    QPainter,
+    QPainterPath,
+    QPen,
+    QPixmap,
+    QPolygonF,
+    QRegion,
+    qAlpha,
+)
+from qtpy.QtWidgets import QFrame, QStyle, QStyleOption
+
 from qwt.null_paintdevice import QwtNullPaintDevice
 from qwt.painter import QwtPainter
 
-from qtpy import PYQT5
-from qtpy.QtGui import (
-    QPaintEngine,
-    QPen,
-    QBrush,
-    QRegion,
-    QImage,
-    QPainterPath,
-    QPixmap,
-    QGradient,
-    QPainter,
-    qAlpha,
-    QPolygonF,
-)
-from qtpy.QtWidgets import QFrame, QStyleOption, QStyle, QStyleOptionFrame
-from qtpy.QtCore import Qt, QSizeF, QEvent, QPointF, QRectF
-from qtpy import QtCore as QC
-
 QT_MAJOR_VERSION = int(QC.__version__.split(".")[0])
+QT_API = os.environ["QT_API"]
+
+if QT_API in ("pyqt", "pyqt4"):
+    from PyQt4.QtGui import QStyleOptionFrameV3 as QStyleOptionFrame
+elif QT_API == "pyside2":
+    from PySide2.QtWidgets import QStyleOptionFrame
+else:
+    from qtpy.QtWidgets import QStyleOptionFrame
 
 
 class Border(object):
@@ -71,8 +80,17 @@ class QwtStyleSheetRecorder(QwtNullPaintDevice):
             self.__origin = state.brushOrigin()
 
     def drawRects(self, rects, count):
-        for i in range(count):
-            self.border.rectList += [rects[i]]
+        if QT_API.startswith("pyside"):
+            # Pyside
+            if isinstance(rects, (QRect, QRectF)):
+                self.border.list = [rects]
+            else:
+                for i in range(count):
+                    self.border.rectList += [rects.getRect().index(i)]
+        else:
+            # PyQt
+            for i in range(count):
+                self.border.rectList += [rects[i]]
 
     def drawPath(self, path):
         rect = QRectF(QPointF(0.0, 0.0), self.__size)
@@ -123,15 +141,6 @@ class QwtStyleSheetRecorder(QwtNullPaintDevice):
                 r.setBottom(rect.bottom())
 
 
-def _rects_conv_PyQt5(rects):
-    # PyQt5 compatibility: the conversion from QRect to QRectF should not
-    # be necessary but it seems to be anyway... PyQt5 bug?
-    if PYQT5:
-        return [QRectF(rect) for rect in rects]
-    else:
-        return rects
-
-
 def qwtDrawBackground(painter, canvas):
     painter.save()
     borderClip = canvas.borderPath(canvas.rect())
@@ -147,7 +156,7 @@ def qwtDrawBackground(painter, canvas):
         if brush.gradient().coordinateMode() == QGradient.ObjectBoundingMode:
             rects += [canvas.rect()]
         else:
-            rects += [painter.clipRegion().rects()]
+            rects += [painter.clipRegion().boundingRect()]
         useRaster = False
         if painter.paintEngine().type() == QPaintEngine.X11:
             useRaster = True
@@ -159,20 +168,22 @@ def qwtDrawBackground(painter, canvas):
                     format_ = QImage.Format_ARGB32
                     break
             image = QImage(canvas.size(), format_)
-            p = QPainter(image)
-            p.setPen(Qt.NoPen)
-            p.setBrush(brush)
-            p.drawRects(_rects_conv_PyQt5(rects))
-            p.end()
+            pntr = QPainter(image)
+            pntr.setPen(Qt.NoPen)
+            pntr.setBrush(brush)
+            for rect in rects:
+                pntr.drawRect(rect)
+            pntr.end()
             painter.drawImage(0, 0, image)
         else:
             painter.setPen(Qt.NoPen)
             painter.setBrush(brush)
-            painter.drawRects(_rects_conv_PyQt5(rects))
+            for rect in rects:
+                painter.drawRect(rect)
     else:
         painter.setPen(Qt.NoPen)
         painter.setBrush(brush)
-        painter.drawRects(_rects_conv_PyQt5(painter.clipRegion().rects()))
+        painter.drawRect(painter.clipRegion().boundingRect())
 
     painter.restore()
 
@@ -298,8 +309,7 @@ def qwtFillBackground(*args):
         else:
             clipRegion = widget.contentsRect()
         bgWidget = qwtBackgroundWidget(widget.parentWidget())
-        for fillRect in fillRects:
-            rect = QRectF(fillRect).toAlignedRect()
+        for rect in fillRects:
             if clipRegion.intersects(rect):
                 pm = QPixmap(rect.size())
                 QwtPainter.fillPixmap(
@@ -731,17 +741,16 @@ class QwtPlotCanvas(QFrame):
                     self.frameStyle(),
                 )
         else:
-            if PYQT5:
-                from qtpy.QtWidgets import QStyleOptionFrame
-            else:
-                try:
-                    from PyQt4.QtGui import QStyleOptionFrameV3 as QStyleOptionFrame
-                except ImportError:
-                    from PySide2.QtWidgets import QStyleOptionFrame
             opt = QStyleOptionFrame()
             opt.initFrom(self)
-            frameShape = self.frameStyle() & QFrame.Shape_Mask
-            frameShadow = self.frameStyle() & QFrame.Shadow_Mask
+            try:
+                shape_mask = QFrame.Shape_Mask.value
+                shadow_mask = QFrame.Shadow_Mask.value
+            except AttributeError:
+                shape_mask = QFrame.Shape_Mask
+                shadow_mask = QFrame.Shadow_Mask
+            frameShape = self.frameStyle() & shape_mask
+            frameShadow = self.frameStyle() & shadow_mask
             opt.frameShape = QFrame.Shape(int(opt.frameShape) | frameShape)
             if frameShape in (
                 QFrame.Box,
@@ -754,9 +763,9 @@ class QwtPlotCanvas(QFrame):
                 opt.midLineWidth = self.midLineWidth()
             else:
                 opt.lineWidth = self.frameWidth()
-            if frameShadow == self.Sunken:
+            if frameShadow == QFrame.Sunken:
                 opt.state |= QStyle.State_Sunken
-            elif frameShadow == self.Raised:
+            elif frameShadow == QFrame.Raised:
                 opt.state |= QStyle.State_Raised
             self.style().drawControl(QStyle.CE_ShapedFrame, opt, painter, self)
 
