@@ -13,15 +13,16 @@ QwtPlotLayout
    :members:
 """
 
-from .text import QwtText
-from .scale_widget import QwtScaleWidget
-from .plot import QwtPlot
-from .scale_draw import QwtAbstractScaleDraw
+import math
 
-from .qt.QtGui import QFont, QRegion
-from .qt.QtCore import QSize, Qt, QRectF
+from qwt.text import QwtText
+from qwt.scale_widget import QwtScaleWidget
+from qwt.plot import QwtPlot
+from qwt.scale_draw import QwtAbstractScaleDraw
+
+from qtpy.QtGui import QFont, QRegion
+from qtpy.QtCore import QSize, Qt, QRectF
 
-import numpy as np
 
 QWIDGETSIZE_MAX = (1 << 24) - 1
 
@@ -80,7 +81,7 @@ class QwtPlotLayout_LayoutData(object):
             self.legend.hScrollExtent = legend.scrollExtent(Qt.Horizontal)
             self.legend.vScrollExtent = legend.scrollExtent(Qt.Vertical)
             hint = legend.sizeHint()
-            w = min([hint.width(), np.floor(rect.width())])
+            w = min([hint.width(), math.floor(rect.width())])
             h = legend.heightForWidth(w)
             if h <= 0:
                 h = hint.height()
@@ -132,7 +133,12 @@ class QwtPlotLayout_LayoutData(object):
                 self.scale[axis].baseLineOffset = 0
                 self.scale[axis].tickOffset = 0.0
                 self.scale[axis].dimWithoutTitle = 0
-        self.canvas.contentsMargins = plot.canvas().getContentsMargins()
+        layout = plot.canvas().layout()
+        if layout is not None:
+            mgn = layout.contentsMargins()
+            self.canvas.contentsMargins = [
+                mgn.left(), mgn.top(), mgn.right(), mgn.bottom()
+            ]
 
 
 class QwtPlotLayout_PrivateData(object):
@@ -159,11 +165,11 @@ class QwtPlotLayout(object):
     a QPrinter, QPixmap/QImage or QSvgRenderer.
 
     .. seealso::
-    
+
         :py:meth:`qwt.plot.QwtPlot.setPlotLayout()`
-    
+
     Valid options:
-    
+
       * `QwtPlotLayout.AlignScales`: Unused
       * `QwtPlotLayout.IgnoreScrollbars`: Ignore the dimension of the scrollbars. There are no scrollbars, when the plot is not rendered to widgets.
       * `QwtPlotLayout.IgnoreFrames`: Ignore all frames.
@@ -192,16 +198,16 @@ class QwtPlotLayout(object):
         Change a margin of the canvas. The margin is the space
         above/below the scale ticks. A negative margin will
         be set to -1, excluding the borders of the scales.
-        
+
         :param int margin: New margin
         :param int axisId: Axis index
-        
+
         .. seealso::
-        
+
             :py:meth:`canvasMargin()`
-        
+
         .. warning::
-        
+
             The margin will have no effect when `alignCanvasToScale()` is True
         """
         if margin < 1:
@@ -216,9 +222,9 @@ class QwtPlotLayout(object):
         """
         :param int axisId: Axis index
         :return: Margin around the scale tick borders
-        
+
         .. seealso::
-        
+
             :py:meth:`setCanvasMargin()`
         """
         if axisId not in QwtPlot.AXES:
@@ -228,31 +234,31 @@ class QwtPlotLayout(object):
     def setAlignCanvasToScales(self, *args):
         """
         Change the align-canvas-to-axis-scales setting.
-        
+
         .. py:method:: setAlignCanvasToScales(on):
-        
+
             Set the align-canvas-to-axis-scales flag for all axes
-            
+
             :param bool on: True/False
-        
+
         .. py:method:: setAlignCanvasToScales(axisId, on):
 
             Change the align-canvas-to-axis-scales setting.
             The canvas may:
-            
+
                 - extend beyond the axis scale ends to maximize its size,
                 - align with the axis scale ends to control its size.
 
-            The axisId parameter is somehow confusing as it identifies a 
-            border of the plot and not the axes, that are aligned. F.e when 
-            `QwtPlot.yLeft` is set, the left end of the the x-axes 
+            The axisId parameter is somehow confusing as it identifies a
+            border of the plot and not the axes, that are aligned. F.e when
+            `QwtPlot.yLeft` is set, the left end of the the x-axes
             (`QwtPlot.xTop`, `QwtPlot.xBottom`) is aligned.
-  
+
             :param int axisId: Axis index
             :param bool on: True/False
-        
+
         .. seealso::
-        
+
             :py:meth:`setAlignCanvasToScale()`,
             :py:meth:`alignCanvasToScale()`
         """
@@ -272,17 +278,17 @@ class QwtPlotLayout(object):
 
     def alignCanvasToScale(self, axisId):
         """
-        Return the align-canvas-to-axis-scales setting. 
+        Return the align-canvas-to-axis-scales setting.
         The canvas may:
-        
+
             - extend beyond the axis scale ends to maximize its size
             - align with the axis scale ends to control its size.
-        
+
         :param int axisId: Axis index
         :return: align-canvas-to-axis-scales setting
-        
+
         .. seealso::
-        
+
             :py:meth:`setAlignCanvasToScale()`, :py:meth:`setCanvasMargin()`
         """
         if axisId not in QwtPlot.AXES:
@@ -293,11 +299,11 @@ class QwtPlotLayout(object):
         """
         Change the spacing of the plot. The spacing is the distance
         between the plot components.
-        
+
         :param int spacing: New spacing
-        
+
         .. seealso::
-        
+
             :py:meth:`setCanvasMargin()`, :py:meth:`spacing()`
         """
         self.__data.spacing = max([0, spacing])
@@ -305,9 +311,9 @@ class QwtPlotLayout(object):
     def spacing(self):
         """
         :return: Spacing
-        
+
         .. seealso::
-        
+
             :py:meth:`margin()`, :py:meth:`setSpacing()`
         """
         return self.__data.spacing
@@ -315,28 +321,28 @@ class QwtPlotLayout(object):
     def setLegendPosition(self, *args):
         """
         Specify the position of the legend
-        
+
         .. py:method:: setLegendPosition(pos, [ratio=0.]):
-        
+
             Specify the position of the legend
-            
+
             :param QwtPlot.LegendPosition pos: Legend position
             :param float ratio: Ratio between legend and the bounding rectangle of title, footer, canvas and axes
-            
-            The legend will be shrunk if it would need more space than the 
-            given ratio. The ratio is limited to ]0.0 .. 1.0]. In case of 
-            <= 0.0 it will be reset to the default ratio. The default 
+
+            The legend will be shrunk if it would need more space than the
+            given ratio. The ratio is limited to ]0.0 .. 1.0]. In case of
+            <= 0.0 it will be reset to the default ratio. The default
             vertical/horizontal ratio is 0.33/0.5.
-            
+
             Valid position values:
-            
+
                 * `QwtPlot.LeftLegend`,
                 * `QwtPlot.RightLegend`,
                 * `QwtPlot.TopLegend`,
                 * `QwtPlot.BottomLegend`
-        
+
         .. seealso::
-        
+
             :py:meth:`setLegendPosition()`
         """
         if len(args) == 2:
@@ -367,7 +373,7 @@ class QwtPlotLayout(object):
         :return: Position of the legend
 
         .. seealso::
-        
+
             :py:meth:`legendPosition()`
         """
         return self.__data.legendPos
@@ -375,16 +381,16 @@ class QwtPlotLayout(object):
     def setLegendRatio(self, ratio):
         """
         Specify the relative size of the legend in the plot
-        
+
         :param float ratio: Ratio between legend and the bounding rectangle of title, footer, canvas and axes
-        
-        The legend will be shrunk if it would need more space than the 
-        given ratio. The ratio is limited to ]0.0 .. 1.0]. In case of 
-        <= 0.0 it will be reset to the default ratio. The default 
+
+        The legend will be shrunk if it would need more space than the
+        given ratio. The ratio is limited to ]0.0 .. 1.0]. In case of
+        <= 0.0 it will be reset to the default ratio. The default
         vertical/horizontal ratio is 0.33/0.5.
 
         .. seealso::
-        
+
             :py:meth:`legendRatio()`
         """
         self.setLegendPosition(self.legendPosition(), ratio)
@@ -394,7 +400,7 @@ class QwtPlotLayout(object):
         :return: The relative size of the legend in the plot.
 
         .. seealso::
-        
+
             :py:meth:`setLegendRatio()`
         """
         return self.__data.legendRatio
@@ -405,11 +411,11 @@ class QwtPlotLayout(object):
 
         This method is intended to be used from derived layouts
         overloading `activate()`
-        
+
         :param QRectF rect: Rectangle
 
         .. seealso::
-        
+
             :py:meth:`titleRect()`, :py:meth:`activate()`
         """
         self.__data.titleRect = rect
@@ -417,9 +423,9 @@ class QwtPlotLayout(object):
     def titleRect(self):
         """
         :return: Geometry for the title
-        
+
         .. seealso::
-        
+
             :py:meth:`invalidate()`, :py:meth:`activate()`
         """
         return self.__data.titleRect
@@ -430,11 +436,11 @@ class QwtPlotLayout(object):
 
         This method is intended to be used from derived layouts
         overloading `activate()`
-        
+
         :param QRectF rect: Rectangle
 
         .. seealso::
-        
+
             :py:meth:`footerRect()`, :py:meth:`activate()`
         """
         self.__data.footerRect = rect
@@ -442,9 +448,9 @@ class QwtPlotLayout(object):
     def footerRect(self):
         """
         :return: Geometry for the footer
-        
+
         .. seealso::
-        
+
             :py:meth:`invalidate()`, :py:meth:`activate()`
         """
         return self.__data.footerRect
@@ -455,11 +461,11 @@ class QwtPlotLayout(object):
 
         This method is intended to be used from derived layouts
         overloading `activate()`
-        
+
         :param QRectF rect: Rectangle for the legend
 
         .. seealso::
-        
+
             :py:meth:`footerRect()`, :py:meth:`activate()`
         """
         self.__data.legendRect = rect
@@ -467,9 +473,9 @@ class QwtPlotLayout(object):
     def legendRect(self):
         """
         :return: Geometry for the legend
-        
+
         .. seealso::
-        
+
             :py:meth:`invalidate()`, :py:meth:`activate()`
         """
         return self.__data.legendRect
@@ -485,7 +491,7 @@ class QwtPlotLayout(object):
         :param QRectF rect: Rectangle for the scale
 
         .. seealso::
-        
+
             :py:meth:`scaleRect()`, :py:meth:`activate()`
         """
         if axis in QwtPlot.AXES:
@@ -495,9 +501,9 @@ class QwtPlotLayout(object):
         """
         :param int axisId: Axis index
         :return: Geometry for the scale
-        
+
         .. seealso::
-        
+
             :py:meth:`invalidate()`, :py:meth:`activate()`
         """
         if axis not in QwtPlot.AXES:
@@ -514,7 +520,7 @@ class QwtPlotLayout(object):
         :param QRectF rect: Rectangle
 
         .. seealso::
-        
+
             :py:meth:`canvasRect()`, :py:meth:`activate()`
         """
         self.__data.canvasRect = rect
@@ -522,9 +528,9 @@ class QwtPlotLayout(object):
     def canvasRect(self):
         """
         :return: Geometry for the canvas
-        
+
         .. seealso::
-        
+
             :py:meth:`invalidate()`, :py:meth:`activate()`
         """
         return self.__data.canvasRect
@@ -532,9 +538,9 @@ class QwtPlotLayout(object):
     def invalidate(self):
         """
         Invalidate the geometry of all components.
-        
+
         .. seealso::
-        
+
             :py:meth:`activate()`
         """
         self.__data.titleRect = QRectF()
@@ -548,9 +554,9 @@ class QwtPlotLayout(object):
         """
         :param qwt.plot.QwtPlot plot: Plot widget
         :return: Minimum size hint
-        
+
         .. seealso::
-        
+
             :py:meth:`qwt.plot.QwtPlot.minimumSizeHint()`
         """
 
@@ -564,7 +570,14 @@ class QwtPlotLayout(object):
 
         scaleData = [_ScaleData() for _i in QwtPlot.AXES]
         canvasBorder = [0 for _i in QwtPlot.AXES]
-        fw, _, _, _ = plot.canvas().getContentsMargins()
+        layout = plot.canvas().layout()
+        if layout is None:
+            left, top, right, bottom = 0, 0, 0, 0
+        else:
+            mgn = layout.contentsMargins()
+            left, top, right, bottom = (
+                mgn.left(), mgn.top(), mgn.right(), mgn.bottom()
+            )
         for axis in QwtPlot.AXES:
             if plot.axisEnabled(axis):
                 scl = plot.axisWidget(axis)
@@ -575,8 +588,8 @@ class QwtPlotLayout(object):
                 sd.minLeft, sd.minLeft = scl.getBorderDistHint()
                 sd.tickOffset = scl.margin()
                 if scl.scaleDraw().hasComponent(QwtAbstractScaleDraw.Ticks):
-                    sd.tickOffset += np.ceil(scl.scaleDraw().maxTickLength())
-            canvasBorder[axis] = fw + self.__data.canvasMargin[axis] + 1
+                    sd.tickOffset += math.ceil(scl.scaleDraw().maxTickLength())
+            canvasBorder[axis] = left + self.__data.canvasMargin[axis] + 1
         for axis in QwtPlot.AXES:
             sd = scaleData[axis]
             if sd.w and axis in (QwtPlot.xBottom, QwtPlot.xTop):
@@ -614,7 +627,6 @@ class QwtPlotLayout(object):
                         shiftTop = scaleData[QwtPlot.xTop].tickOffset
                     sd.h -= shiftTop
         canvas = plot.canvas()
-        left, top, right, bottom = canvas.getContentsMargins()
         minCanvasSize = canvas.minimumSize()
         w = scaleData[QwtPlot.yLeft].w + scaleData[QwtPlot.yRight].w
         cw = (
@@ -674,7 +686,7 @@ class QwtPlotLayout(object):
     def layoutLegend(self, options, rect):
         """
         Find the geometry for the legend
-        
+
         :param options: Options how to layout the legend
         :param QRectF rect: Rectangle where to place the legend
         :return: Geometry for the legend
@@ -704,7 +716,7 @@ class QwtPlotLayout(object):
     def alignLegend(self, canvasRect, legendRect):
         """
         Align the legend to the canvas
-        
+
         :param QRectF canvasRect: Geometry of the canvas
         :param QRectF legendRect: Maximum geometry for the legend
         :return: Geometry for the aligned legend
@@ -724,13 +736,13 @@ class QwtPlotLayout(object):
         """
         Expand all line breaks in text labels, and calculate the height
         of their widgets in orientation of the text.
-        
+
         :param options: Options how to layout the legend
         :param QRectF rect: Bounding rectangle for title, footer, axes and canvas.
         :return: tuple `(dimTitle, dimFooter, dimAxes)`
-        
+
         Returns:
-        
+
             * `dimTitle`: Expanded height of the title widget
             * `dimFooter`: Expanded height of the footer widget
             * `dimAxes`: Expanded heights of the axis in axis orientation.
@@ -765,7 +777,7 @@ class QwtPlotLayout(object):
                     != self.__data.layoutData.scale[QwtPlot.yRight].isEnabled
                 ):
                     w -= dimAxes[QwtPlot.yLeft] + dimAxes[QwtPlot.yRight]
-                d = np.ceil(self.__data.layoutData.title.text.heightForWidth(w))
+                d = math.ceil(self.__data.layoutData.title.text.heightForWidth(w))
                 if not (options & self.IgnoreFrames):
                     d += 2 * self.__data.layoutData.title.frameWidth
                 if d > dimTitle:
@@ -781,7 +793,7 @@ class QwtPlotLayout(object):
                     != self.__data.layoutData.scale[QwtPlot.yRight].isEnabled
                 ):
                     w -= dimAxes[QwtPlot.yLeft] + dimAxes[QwtPlot.yRight]
-                d = np.ceil(self.__data.layoutData.footer.text.heightForWidth(w))
+                d = math.ceil(self.__data.layoutData.footer.text.heightForWidth(w))
                 if not (options & self.IgnoreFrames):
                     d += 2 * self.__data.layoutData.footer.frameWidth
                 if d > dimFooter:
@@ -848,7 +860,9 @@ class QwtPlotLayout(object):
                             length -= dimTitle + self.__data.spacing
                     d = scaleData.dimWithoutTitle
                     if not scaleData.scaleWidget.title().isEmpty():
-                        d += scaleData.scaleWidget.titleHeightForWidth(np.floor(length))
+                        d += scaleData.scaleWidget.titleHeightForWidth(
+                            math.floor(length)
+                        )
                     if d > dimAxes[axis]:
                         dimAxes[axis] = d
                         done = False
@@ -858,7 +872,7 @@ class QwtPlotLayout(object):
         """
         Align the ticks of the axis to the canvas borders using
         the empty corners.
-        
+
         :param options: Options how to layout the legend
         :param QRectF canvasRect: Geometry of the canvas ( IN/OUT )
         :param QRectF scaleRect: Geometry of the scales ( IN/OUT )
@@ -1016,7 +1030,7 @@ class QwtPlotLayout(object):
     def activate(self, plot, plotRect, options=0x00):
         """
         Recalculate the geometry of all components.
-        
+
         :param qwt.plot.QwtPlot plot: Plot to be layout
         :param QRectF plotRect: Rectangle where to place the components
         :param options: Layout options
@@ -1031,9 +1045,11 @@ class QwtPlotLayout(object):
         ):
             self.__data.legendRect = self.layoutLegend(options, rect)
             region = QRegion(rect.toRect())
-            rect = region.subtracted(
-                QRegion(self.__data.legendRect.toRect())
-            ).boundingRect()
+            rect = QRectF(
+                region.subtracted(
+                    QRegion(self.__data.legendRect.toRect())
+                ).boundingRect()
+            )
             if self.__data.legendPos == QwtPlot.LeftLegend:
                 rect.setLeft(rect.left() + self.__data.spacing)
             elif self.__data.legendPos == QwtPlot.RightLegend:
@@ -1142,4 +1158,3 @@ class QwtPlotLayout(object):
             self.__data.legendRect = self.alignLegend(
                 self.__data.canvasRect, self.__data.legendRect
             )
-
