@@ -15,24 +15,23 @@ QwtSymbol
 
 import math
 
+from qtpy.QtCore import QLineF, QPoint, QPointF, QRect, QRectF, QSize, QSizeF, Qt
+from qtpy.QtGui import (
+    QBrush,
+    QPainter,
+    QPainterPath,
+    QPen,
+    QPixmap,
+    QPolygonF,
+    QTransform,
+)
+from qtpy.QtSvg import QSvgRenderer
+
 from qwt.graphic import QwtGraphic
 from qwt.painter import QwtPainter
 
-from qtpy.QtGui import (
-    QPainter,
-    QTransform,
-    QPixmap,
-    QPen,
-    QPolygonF,
-    QPainterPath,
-    QBrush,
-)
-from qtpy.QtCore import QSize, QRect, QPointF, QRectF, QSizeF, Qt, QPoint, QLineF
-from qtpy.QtSvg import QSvgRenderer
-
 
 class QwtTriangle(object):
-
     # enum Type
     Left, Right, Up, Down = list(range(4))
 
@@ -255,7 +254,7 @@ def qwtDrawStar1Symbols(painter, points, numPoints, symbol):
     sqrt1_2 = math.sqrt(0.5)
     r = QRectF(0, 0, size.width(), size.height())
     for pos in points:
-        r.moveCenter(pos.toPoint())
+        r.moveCenter(pos)
         c = QPointF(r.center())
         d1 = r.width() / 2.0 * (1.0 - sqrt1_2)
         painter.drawLine(
@@ -353,11 +352,7 @@ class QwtSymbol_PrivateData(object):
 
         self.path = Path()
 
-        class Pixmap(object):
-            def __init__(self):
-                self.pixmap = QPixmap()
-
-        self.pixmap = None  # Pixmap()
+        self.pixmap = None
 
         class Graphic(object):
             def __init__(self):
@@ -734,7 +729,7 @@ class QwtSymbol(object):
             `brush()` and `pen()` have no effect
         """
         self.__data.style = QwtSymbol.Pixmap
-        self.__data.pixmap.pixmap = pixmap
+        self.__data.pixmap = pixmap
 
     def pixmap(self):
         """
@@ -744,7 +739,9 @@ class QwtSymbol(object):
 
             :py:meth:`setPixmap()`
         """
-        return self.__data.pixmap.pixmap
+        if self.__data.pixmap is None:
+            return QPixmap()
+        return self.__data.pixmap
 
     def setGraphic(self, graphic):
         """
@@ -1208,7 +1205,7 @@ class QwtSymbol(object):
             pinPointTranslation = True
         elif self.__data.style == QwtSymbol.Pixmap:
             if self.__data.size.isEmpty():
-                rect.setSize(QSizeF(self.__data.pixmap.pixmap.size()))
+                rect.setSize(QSizeF(self.pixmap().size()))
             else:
                 rect.setSize(QSizeF(self.__data.size))
             pinPointTranslation = True
